import os
import subprocess
import sys

import click
from cookiecutter import exceptions
from cookiecutter.main import cookiecutter
from .helper import windows_success_msg, common_success_msg

# CONTANTS
__version__ = "0.1.1"


@click.group()
@click.version_option(__version__)
def cli():
    pass


@cli.command()
@click.argument("project_name")
def create_project(project_name):
    """Creates a new Flask project"""

    # parse project info
    project_slug = project_name.lower().replace("-", "_")

    # Check for directory exists or not
    if os.path.exists(project_name):
        click.secho(
            "\nError! Directory with {} name already exists!\n".format(project_name),
            fg="red",
        )
        exit()

    click.secho("\nCreating a new Flask app in {}.".format(os.getcwd()))

    try:
        cookiecutter(
            "https://github.com/flaskspot/simple-flask-boilerplate.git",
            no_input=True,
            extra_context={"project_name": project_name, "project_slug": project_slug},
        )
        # After successfull Installation
        click.secho(
            "\nSuccess! Created {project_name} at {cwd}/{project_name}.".format(
                project_name=project_name, cwd=os.getcwd()
            ),
            fg="green",
        )
        if sys.platform == 'win32' or sys.platform == 'cygwin':
            message = windows_success_msg.format(project_name=project_name)
        else:
            message = common_success_msg.format(project_name=project_name)

        click.secho(message)

    except (
        exceptions.NonTemplatedInputDirException,
        exceptions.UnknownTemplateDirException,
        exceptions.ContextDecodingException,
        exceptions.ConfigDoesNotExistException,
        exceptions.OutputDirExistsException,
    ):
        click.secho("Unknown Exception!", fg="red")
    except exceptions.VCSNotInstalled:
        click.secho(
            "\nGit not installed, Please install git to use FlaskSpot!", fg="red"
        )



windows_success_msg = """
Inside that project directory, you can run serval commands:

    python manage.py --help
        Check all commands

You can begin by typing:

    cd {project_name}
    setup your virtual environment
    pip install -r requirements.txt
    python manage.py runserver

"""


common_success_msg = """
Inside that project directory, you can run serval commands:

    make help
        Shows all make commands
    
    make install
        Installs dependency from requirements.txt
    
    make run
        Runs flask application

You can begin by typing:

    cd {project_name}
    setup your virtual environment
    make install
    make run

"""


from os import read
from setuptools import setup, find_packages

with open('README.md') as f:
    readme = f.read()


setup(
    name='flaskspot',
    version='0.1.1',
    description="FlaskSpot provides Starter Kits for Flask.",
    long_description=readme,
    long_description_content_type='text/markdown',
    author="Abhijeet Sonawane",
    author_email="abhijeet.sonawane001@gmail.com",
    license="MIT",
    packages=find_packages(),
    include_package_data=True,
    install_requires=["click==7.1.2", "cookiecutter==1.7.2", "colorama"],
    entry_points={
        "console_scripts": [
            "flaskspot = flaskspot:cli"
        ]
    },
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    keywords='flaskspot flaskproject flaskstarterkit'
)